@@ -2,8 +2,8 @@ package Plack::Middleware::RemoveRedundantBody;
 use strict;
 use warnings;
 use parent qw( Plack::Middleware );
-
 use Plack::Util;
+
 # ABSTRACT: Plack::Middleware which sets removes body for HTTP response if it's not required
 
 sub call {
@@ -15,11 +15,11 @@ sub call {
         my $response = shift;
         my $status = $response->[0];
         my $headers = Plack::Util::headers($response->[1]); # first index contains HTTP header
-        if( $status =~ /^(1\d\d|[23]04)$/ ) {
+        if( Plack::Util::status_with_no_entity_body($response->[0]) ) {
             $response->[2] = [];
             $headers->remove("Content-Length");
-            return $response;
 	}
+	return;
     });
 }
 
@@ -29,13 +29,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Plack::Middleware::RemoveRedundantBody - Plack::Middleware which sets removes body for HTTP response if it's not required
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -59,6 +61,10 @@ This module removes body in HTTP response, if it's not required.
 
 Plack::Middleware::RemoveRedundantBody - removes body for HTTP response if it's not required
 
+=head1 CONTRIBUTORS
+
+John Napiorkowski <jjn1056@yahoo.com>
+
 =head1 AUTHOR
 
 Upasana <me@upasana.me>
